@@ -3,7 +3,7 @@ from typing import Dict, List, Optional, Tuple, Union
 from cognite.client._api_client import APIClient
 from cognite.client.utils._auxiliary import assert_type, to_camel_case, to_snake_case
 
-from cognite.experimental.data_classes import Annotation, AnnotationFilter, AnnotationList
+from cognite.experimental.data_classes import Annotation, AnnotationFilter, AnnotationList, AnnotationUpdate
 
 
 class AnnotationsAPI(APIClient):
@@ -25,12 +25,12 @@ class AnnotationsAPI(APIClient):
         assert_type(annotations, "annotation", [Annotation, list])
         return self._create_multiple(resource_path=self._RESOURCE_PATH + "/", items=annotations)
 
-    def list(self, limit: int = 100, filter: Union[AnnotationFilter, Dict] = {}) -> AnnotationList:
-        """List annotations
+    def list(self, filter: Union[AnnotationFilter, Dict], limit: int = 100) -> AnnotationList:
+        """List annotations.
 
         Args:
             limit (int): Maximum number of annotations to return. Defaults to 100.
-            filter (AnnotationFilter, optional): If not None, return annotations with parameter values that matches what is specified. Defaults to None.
+            filter (AnnotationFilter, optional): Return annotations with parameter values that matches what is specified. Note that annotated_resource_type is always required.
 
         Returns:
             AnnotationList: list of annotations
@@ -52,6 +52,16 @@ class AnnotationsAPI(APIClient):
         response = self._post(self._RESOURCE_PATH + "/list", json={"limit": limit, "filter": filter})
         return AnnotationList._load(response.json()["items"])
 
+    def update(
+        self, item: Union[Annotation, AnnotationUpdate, List[Union[Annotation, AnnotationUpdate]]]
+    ) -> Union[Annotation, AnnotationList]:
+        """Update annotations
+
+        Args:
+            id (Union[int, List[int]]): ID or list of IDs to be deleted
+        """
+        return self._update_multiple(items=item)
+
     def delete(self, id: Union[int, List[int]]) -> None:
         """Delete annotations
 
